==> 0.2.3.tar.gz: lib/src/view/default_editors.dart <==
part of fields.view;

class BoolEditor extends FieldEditor<bool> {
  
  CheckboxInputElement _input;
  Element _element;
  Element get element => _element;
  
  BoolEditor(Field field) : super(field) {
    _element = div(() {
      _input = input()
      ..type = 'checkbox'
      ..onChange.listen((_) {
        this.value = _input.checked;
      });
      if (field.description != null) {
        span()..text = field.description;
      }
    });
    
    render();
  }
      
  void render() {
    _input
    ..disabled = isValueReadOnly
    ..checked = value;
  }
}

class ColorEditor extends FieldEditor<String> {
  
  InputElement _picker;
  InputElement _display;
  Element _element;
  Element get element => _element;
  
  ColorEditor(Field field) : super(field) {
    _element = span(() {
      _picker = input()
      ..type = 'color'
      ..style.float = 'left'
      ..onChange.listen((_) {
        _display.value = _picker.value;         
        this.value = _picker.value;
      });
      div(() {
        _display = input()
        ..type = 'text'
        ..disabled = true;
      })
      ..style.overflow = 'hidden';
    });
    
    render();
  }
  
  void render() {
    _picker
    ..disabled = isValueReadOnly
    ..value = value;
    _display.value = value;
  }
}

class DateTimeEditor extends FieldEditor<DateTime> {
  
  DateInputElement _input;
  Element get element => _input;
  
  DateTimeEditor(Field field) : super(field) {
    _input = input()
    ..type = 'date' // TODO(rms): investigate 'datetime-local'
    ..onChange.listen((_) {
      this.value = _input.valueAsDate;
    });
    
    render();
  }
  
  void render() {
    _input
    ..disabled = isValueReadOnly
    ..valueAsDate = value;
  }
}

class DefaultEditor extends FieldEditor<String> {
  
  InputElement _input;
  Element get element => _input;
    
  DefaultEditor(Field field) : super(field) {
    _input = input()
    ..type = 'text'
    ..onInput.listen((_) {
      try {
        this.value = _input.value;
        _input.classes.remove('error');
      } catch(_) {
        _input.classes.add('error');
      }
    });
    
    render();
  }
  
  void render() {
    _input
    ..disabled = isValueReadOnly
    ..value = value;
  }
}

class NumberEditor extends FieldEditor<num> {
  
  InputElement _input;
  Element get element => _input;
  
  NumberEditor(Field field) : super(field) {
    _input = input()
    ..type = 'number'
    ..onChange.listen((_) {
      this.value = _input.valueAsNumber;
    });
    
    final match = (a) => a is UseRange;
    if (field.annotations.any(match)) {
      UseRange range = field.annotations.firstWhere(match);
      range.applyTo(_input);
    }
    
    render();
  }
  
  void render() {
    _input
    ..disabled = isValueReadOnly
    ..valueAsNumber = value;
  }
}

class RangeEditor extends FieldEditor<num> {
  
  InputElement _range;
  InputElement _display;
  Element _element;
  Element get element => _element;
  
  RangeEditor(Field field) : super(field) {
    _element = span(() {
      _range = input()
      ..type = 'range'
      ..style.float = 'left'
      ..onChange.listen((_) {
        _display.value = _range.value; 
        this.value = _range.valueAsNumber;
      });
      
      div(() {
        _display = input()
        ..type = 'text'
        ..disabled = true;
      })
      ..style.overflow = 'hidden';
    });

    final match = (a) => a is UseRange;
    if (field.annotations.any(match)) {
      UseRange range = field.annotations.firstWhere(match);
      range.applyTo(_range);
    }
    
    render();
  }
  
  void render() {
    _range
    ..disabled = isValueReadOnly
    ..valueAsNumber = value;
    _display.value = value.toString();
  }
}

class SelectEditor extends FieldEditor<String> {
  
  SelectElement _select;
  Element get element => _select;
      
  SelectEditor(Field field) : super(field) {
    _select = select(() {      
      final isUseValues = (a) => a is UseValues;
      if (field.annotations.any(isUseValues)) {
        UseValues useValues = field.annotations.firstWhere(isUseValues);
        for (var v in useValues.values) {
          String valueString;
          if (field.transform != null) {
            valueString = field.transform(v);
          } else if (FieldTransform.canTransform(v.runtimeType, String)) {
            valueString = FieldTransform.transform(v, v.runtimeType, String);
          } else {
            valueString = v.toString();
          }
          option()
          ..text = valueString
          ..value = valueString;
        }
      }
    })
    ..onChange.listen((_) {
      this.value = _select.value;
    });
    
    render();
  }
  
  void render() {
    _select
    ..disabled = isValueReadOnly
    ..value = value;
  }
}

==> 0.4.0.tar.gz: lib/src/view/default_editors.dart <==
part of fields.view;

class BoolEditor extends FieldEditor<bool> {
  
  CheckboxInputElement _input;
  Element _element;
  Element get element => _element;
  
  BoolEditor(Field field) : super(field) {
    _element = div(() {
      _input = input()
      ..type = 'checkbox'
      ..onChange.listen((_) {
        this.value = _input.checked;
      });
      if (field.description != null) {
        span()..text = field.description;
      }
    });
  }
      
  void refreshElement() {
    _input
    ..disabled = !isEnabled
    ..checked = value;
  }
}

class ColorEditor extends FieldEditor<String> {
  
  InputElement _picker;
  InputElement _display;
  Element _element;
  Element get element => _element;
  
  ColorEditor(Field field) : super(field) {
    _element = span(() {
      _picker = input()
      ..type = 'color'
      ..style.float = 'left'
      ..onChange.listen((_) {
        _display.value = _picker.value;         
        this.value = _picker.value;
      });
      div(() {
        _display = input()
        ..type = 'text'
        ..disabled = true;
      })
      ..style.overflow = 'hidden';
    });
  }
  
  void refreshElement() {
    _picker
    ..disabled = !isEnabled
    ..value = value;
    _display.value = value;
  }
}

class DateTimeEditor extends FieldEditor<DateTime> {
  
  DateInputElement _input;
  Element get element => _input;
  
  DateTimeEditor(Field field) : super(field) {
    _input = input()
    ..type = 'date' // TODO(rms): investigate 'datetime-local'
    ..onChange.listen((_) {
      this.value = _input.valueAsDate;
    });
  }
  
  void refreshElement() {
    _input
    ..disabled = !isEnabled
    ..valueAsDate = value;
  }
}

class DefaultEditor extends FieldEditor<String> {
  
  InputElement _input;
  Element get element => _input;
    
  DefaultEditor(Field field) : super(field) {
    _input = input()
    ..type = 'text'
    ..onInput.listen((_) {
      try {
        this.value = _input.value;
        _input.classes.remove('error');
      } catch(_) {
        _input.classes.add('error');
      }
    });
  }
  
  void refreshElement() {
    _input
    ..disabled = !isEnabled
    ..value = value;
  }
}

class NumberEditor extends FieldEditor<num> {
  
  InputElement _input;
  Element get element => _input;
  
  NumberEditor(Field field) : super(field) {
    _input = input()
    ..type = 'number'
    ..onChange.listen((_) {
      this.value = _input.valueAsNumber;
    });
    
    final match = (a) => a is UseRange;
    if (field.annotations.any(match)) {
      UseRange range = field.annotations.firstWhere(match);
      range.applyTo(_input);
    }
  }
  
  void refreshElement() {
    _input
    ..disabled = !isEnabled
    ..valueAsNumber = value;
  }
}

class RangeEditor extends FieldEditor<num> {
  
  InputElement _range;
  InputElement _display;
  Element _element;
  Element get element => _element;
  
  RangeEditor(Field field) : super(field) {
    _element = span(() {
      _range = input()
      ..type = 'range'
      ..style.float = 'left'
      ..onChange.listen((_) {
        _display.value = _range.value; 
        this.value = _range.valueAsNumber;
      });
      
      div(() {
        _display = input()
        ..type = 'text'
        ..disabled = true;
      })
      ..style.overflow = 'hidden';
    });

    final match = (a) => a is UseRange;
    if (field.annotations.any(match)) {
      UseRange range = field.annotations.firstWhere(match);
      range.applyTo(_range);
    }
  }
  
  void refreshElement() {
    _range
    ..disabled = !isEnabled
    ..valueAsNumber = value;
    _display.value = value.toString();
  }
}

class SelectEditor extends FieldEditor<String> {
  
  SelectElement _select;
  Element get element => _select;
      
  SelectEditor(Field field) : super(field) {
    _select = select(() {      
      final isUseValues = (a) => a is UseValues;
      if (field.annotations.any(isUseValues)) {
        UseValues useValues = field.annotations.firstWhere(isUseValues);
        for (var v in useValues.values) {
          String valueString;
          if (field.transform != null) {
            valueString = field.transform(v);
          } else if (ValueTransform.canTransform(v.runtimeType, String)) {
            valueString = ValueTransform.transform(v, v.runtimeType, String);
          } else {
            valueString = v.toString();
          }
          option()
          ..text = valueString
          ..value = valueString;
        }
      }
    })
    ..onChange.listen((_) {
      this.value = _select.value;
    });
  }
  
  void refreshElement() {
    _select
    ..disabled = !isEnabled
    ..value = value;
  }
}
